# Generated by Django 3.2.6 on 2021-08-10 14:46

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("signalcontrol", "0002_auto_20200618_1611"),
    ]

    operations = [
        migrations.AlterField(
            model_name="signalcontrol",
            name="id",
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID"),
        ),
    ]
